-------------------------------------------------------------------------------
-- ElvUI Chat Tweaks By Lockslap (US, Bleeding Hollow)
-- <Borderline Amazing>, http://ba-guild.com
-- Based on functionality provided by Prat and/or Chatter
-------------------------------------------------------------------------------
local Module	= ElvUI_ChatTweaks:NewModule("XP Gains", "AceConsole-3.0")
local L			= ElvUI_ChatTweaks.L
Module.name		= L["XP Gains"]

local matches	= {
	COMBATLOG_XPGAIN_EXHAUSTION1:gsub("%%s", "(.+)"):gsub("%%d", "(%%d+)"),
	COMBATLOG_XPGAIN_EXHAUSTION1_GROUP:gsub("%%s", "(.+)"):gsub("%%d", "(%%d+)"),
	COMBATLOG_XPGAIN_EXHAUSTION1_RAID:gsub("%%s", "(.+)"):gsub("%%d", "(%%d+"),
	COMBATLOG_XPGAIN_FIRSTPERSON:gsub("%%s", "(.+)"):gsub("%%d", "(%%d+)"),
	COMBATLOG_XPGAIN_FIRSTPERSON_GROUP:gsub("%%s", "(.+)"):gsub("%%d", "(%%d+)"),
	COMBATLOG_XPGAIN_FIRSTPERSON_RAID:gsub("%%s", "(.+)"):gsub("%%d", "(%%d+)"),
	COMBATLOG_XPGAIN_FIRSTPERSON_UNNAMED:gsub("%%s", "(.+)"):gsub("%%d", "(%%d+)"),
	COMBATLOG_XPGAIN_FIRSTPERSON_UNNAMED_GROUP:gsub("%%s", "(.+)"):gsub("%%d", "(%%d+)"),
	COMBATLOG_XPGAIN_FIRSTPERSON_UNNAMED_RAID:gsub("%%s", "(.+)"):gsub("%%d", "(%%d+)"),
	COMBATLOG_XPGAIN_QUEST:gsub("%%s", "(.+)"):gsub("%%d", "(%%d+)"),
}
local yellowString = "|cffffff00%s|r"

local db, options
local defaults = {
	profile = {
		-- rested xp
		xpRested		= L["%s died, +%d xp (%sxp rested)"],
		xpRestedGroup	= L["%s died, +%d xp (%sxp rested, +%d group bonus)"],
		xpRestedRaid	= L["%s died, +%d xp (%sxp rested, -%d raid penalty)"],
		
		-- regular xp
		xpRegular		= L["%s died, +%d xp"],
		xpRegularGroup	= L["%s died, +%d xp (+%d group bonus)"],
		xpRegularRaid	= L["%s died, +%d xp (-%d raid penalty)"],
		
		-- unnamed mob xp
		xpUnnamed		= L["+%d xp"],
		xpUnnamedGroup	= L["+%d xp (+%d group bonus)"],
		xpUnnamedRaid	= L["+%d xp (-%d raid penalty)"],
	}
}

local function XPGainsFilter(self, event, message, ...)

end

function Module:OnEnable()
	ChatFrame_AddMessageEventFilter("CHAT_MSG_COMABT_XP_GAIN", XPGainsFilter)
end

function Module:OnDisable()
	ChatFrame_RemoveMessageEventFilter("CHAT_MSG_COMBAT_XP_GAIN", XPGainsFilter)
end

function Module:OnInitialize()
	self.db = ElvUI_ChatTweaks.db:RegisterNamespace("XPGain", defaults)
	db = self.db.profile
	Module.debug = ElvUI_ChatTweaks.db.profile.debugging
end

function Module:Info()
	return L["Add more information to the XP gain messages."]
end

function Module:GetOptions()
	if not options then
		options = {
			xpRestedDesc = {
				type	= "description",
				order	= 13,
				width	= "normal",
				name	= yellowString:format(L["Rested XP:"]),
			},
			xpRested = {
				type	= "input",
				order	= 14,
				width	= "double",
				name	= "",
				desc	= "",
				get		= function() return db.xpRested end,
				set		= function(_, value) db.xpRested = value end,
			},
			xpRestedGroupDesc = {
				type	= "description",
				order	= 15,
				width	= "normal",
				name	= yellowString:format(L["Rested XP w/ Group Bonus:"]),
			},
			xpRestedGroup = {
				type	= "input",
				order	= 16,
				width	= "double",
				name	= "",
				desc	= "",
				get		= function() return db.xpRestedGroup end,
				set		= function(_, value) db.xpRestedGroup = value end,
			},
			xpRestedRaidDesc = {
				type	= "description",
				order	= 17,
				width	= "normal",
				name	= yellowString:format(L["Rested XP w/ Raid Penalty:"]),
			},
			xpRestedRaid = {
				type	= "input",
				order	= 18,
				width	= "double",
				name	= "",
				desc	= "",
				get		= function() return db.xpRestedRaid end,
				set		= function(_, value) db.xpRestedRaid = value end,
			},
			xpRegularDesc = {
				type	= "description",
				order	= 19,
				width	= "normal",
				name	= yellowString:format(L["Regular XP:"]),
			},
			xpRegular = {
				type	= "input",
				order	= 20,
				width	= "double",
				name	= "",
				desc	= "",
				get		= function() return db.xpRegular end,
				set		= function(_, value) db.xpRegular = value end,
			},
			xpRegularGroupDesc = {
				type	= "description",
				order	= 21,
				width	= "normal",
				name	= yellowString:format(L["Regular XP w/ Group Bonus:"]),
			},
			xpRegularGroup = {
				type	= "input",
				order	= 22,
				width	= "double",
				name	= "",
				desc	= "",
				get		= function() return db.xpRegularGroup end,
				set		= function(_, value) db.xpRegularGroup = value end,
			},
			xpRegularRaidDesc = {
				type	= "description",
				order	= 23,
				width	= "normal",
				name	= yellowString:format(L["Regular XP w/ Raid Penalty:"]),
			},
			xpRegularRaid = {
				type	= "input",
				order	= 24,
				width	= "double",
				name	= "",
				desc	= "",
				get		= function() return db.xpRegularRaid end,
				set		= function(_, value) db.xpRegularRaid = value end,
			},
			xpUnnamedDesc = {
				type	= "description",
				order	= 25,
				width	= "normal",
				name	= yellowString:format(L["Unnamed Mob XP:"]),
			},
			xpUnnamed = {
				type	= "input",
				order	= 26,
				width	= "double",
				name	= "",
				desc	= "",
				get		= function() return db.xpUnnamed end,
				set		= function(_, value) db.xpUnnamed = value end,
			},
			xpUnnamedGroupDesc = {
				type	= "description",
				order	= 27,
				width	= "normal",
				name	= yellowString:format(L["Unnamed Mob XP w/ Group Bonus:"]),
			},
			xpUnnamedGroup = {
				type	= "input",
				order	= 28,
				width	= "double",
				name	= "",
				desc	= "",
				get		= function() return db.xpUnnamedGroup end,
				set		= function(_, value) db.xpUnnamedGroup = value end,
			},
			xpUnnamedRaidDesc = {
				type	= "description",
				order	= 29,
				width	= "normal",
				name	= yellowString:format(L["Unnamed Mob w/ Raid Penalty:"]),
			},
			xpUnnamedRaid = {
				type	= "input",
				order	= 30,
				width	= "double",
				name	= "",
				desc	= "",
				get		= function() return db.xpUnnamedRaid end,
				set		= function(_, value) db.xpUnnamedRaid = value end,
			},
		}
	end
	return options
end